@@ -34,7 +34,7 @@ abstract class ControlPanel
     /**
      * @var string
      */
-    const PANEL_API_VERSION = '1.13.4';
+    const PANEL_API_VERSION = '1.13.4.4';
 
     /**
      * @since 1.9
@@ -953,6 +953,10 @@ abstract class ControlPanel
     public static function checkPanelAPICompatibility( $panelAPIVer )
     {
         $supportedAPIVers = array (
+            '1.13.4.4',
+            '1.13.4.3',
+            '1.13.4.2',
+            '1.13.4.1',
             '1.13.4',
             '1.13.3.1',
             '1.13.3',
